All of lore.kernel.org
 help / color / mirror / Atom feed
* [lm-sensors] Jetway NC92-330-LF motherboard sensors.conf
@ 2009-06-05 11:29 Maciej Żenczykowski
  2009-06-15 12:11 ` Jean Delvare
                   ` (3 more replies)
  0 siblings, 4 replies; 5+ messages in thread
From: Maciej Żenczykowski @ 2009-06-05 11:29 UTC (permalink / raw)
  To: lm-sensors

[-- Attachment #1: Type: text/plain, Size: 464 bytes --]

Hi,

submitting a sensors.conf file for a Jetway NC92-330-LF motherboard
with f71882fg monitoring chip.

# uname -a
Linux gaia 2.6.29.4-168.mz1.fc11.x86_64 #1 SMP Fri Jun 5 11:10:05 CEST
2009 x86_64 x86_64 x86_64 GNU/Linux

# lsmod | head -n 5
Module                  Size  Used by
f71882fg               27120  0
coretemp                6768  0

Also including a slight patch to coretemp.c for atom support.

Hope you include the conf in the wiki.
Thanks,
Maciej

[-- Attachment #2: sensors3.conf --]
[-- Type: application/octet-stream, Size: 1904 bytes --]

# Jetway NC92-330-LF

chip "f71862fg-*"

    label in0 "Vcc3V"
    label in1 "Vcore"
    label in2 "   NB"
    label in3 "+ 5V"
    label in4 "+12V"
    label in5 "5VSB"
    label in6 "VDIMM"
    label in7 "VSB3V"
    label in8 "Vbat"

    label fan1 "CPUFAN"
    label fan2 "SYSFAN1"
    label fan3 "SYSFAN2"

    label temp1 "?CPU Temp"
    label temp2 "?Sys Temp"
    label temp3 "???? Temp"

# According to datasheet, 3VCC/VSB/VBAT
# (ie. Vcc3V/VSB3V/Vbat, or in0/in7/in8)
# use internal R1=R2=150K Ohm resistors
#
# remember V_in_to_chip = V_real * R2 / (R1 + R2)
# (where V_real----R1---*----V_in_to_chip) [max 2.048V]
# (                     |                )
# (                    R2                )
# (                     |                )
# (                    GND               )
#
# It would seem that VDIMM is the same...
# Hence those four are set to use "@*2, @/2"
#
# The values of 5.25 for +5V and 5VSB and 11 for +12V
# are from the datasheet as well (after juggling):
#
# VCORE    R1=1K   R2=inf VCORE  -> *1
# VRAM     R1=10K  R2=10K VIN2   -> *2
# VCHIPSET R1=4.7K R2=10K VIN3   -> *1.47
# VCC5V    R1=20K  R2=4.7 VIN4   -> *5.255319148
# +12V     R1=200K R2=20K VIN5   -> *11
# VCC1.5V  R1=10K  R2=inf VIN6   -> *1

    compute in0 @*2, @/2
    compute in1 @, @
    compute in2 @, @
    compute in3 @*5.255319148, @/5.255319148
    compute in4 @*11, @/11
    compute in5 @*5.255319148, @/5.255319148
    compute in6 @*2, @/2
    compute in7 @*2, @/2
    compute in8 @*2, @/2

#   set temp1_type 2
    set temp1_max        85
    set temp1_max_hyst   81
    set temp1_crit       65
#   set temp1_crit_hyst  61
#   set temp2_type 2
    set temp2_max        85
    set temp2_max_hyst   81
    set temp2_crit      100
#   set temp2_crit_hyst  96
#   set temp3_type 2
    set temp3_max        70
    set temp3_max_hyst   68
    set temp3_crit       85
#   set temp3_crit_hyst  83


[-- Attachment #3: linux-2.6-mz-atom_coretemp.patch --]
[-- Type: application/octet-stream, Size: 3254 bytes --]

diff -Naur vanilla-2.6.29/Documentation/hwmon/coretemp vanilla-2.6.29.coretemp/Documentation/hwmon/coretemp
--- vanilla-2.6.29/Documentation/hwmon/coretemp	2009-03-24 00:12:14.000000000 +0100
+++ vanilla-2.6.29.coretemp/Documentation/hwmon/coretemp	2009-06-05 09:37:21.263124574 +0200
@@ -4,7 +4,7 @@
 Supported chips:
   * All Intel Core family
     Prefix: 'coretemp'
-    CPUID: family 0x6, models 0xe, 0xf, 0x16, 0x17
+    CPUID: family 0x6, models 0xe, 0xf, 0x16, 0x17, 0x1c
     Datasheet: Intel 64 and IA-32 Architectures Software Developer's Manual
                Volume 3A: System Programming Guide
                http://softwarecommunity.intel.com/Wiki/Mobility/720.htm
@@ -14,10 +14,11 @@
 Description
 -----------
 
-This driver permits reading temperature sensor embedded inside Intel Core CPU.
-Temperature is measured in degrees Celsius and measurement resolution is
-1 degree C. Valid temperatures are from 0 to TjMax degrees C, because
-the actual value of temperature register is in fact a delta from TjMax.
+This driver permits reading temperature sensor embedded inside Intel
+Core and Intel Atom CPUs. Temperature is measured in degrees Celsius
+and measurement resolution is 1 degree C. Valid temperatures are from 0
+to TjMax degrees C, because the actual value of temperature register is
+in fact a delta from TjMax.
 
 Temperature known as TjMax is the maximum junction temperature of processor.
 Intel defines this temperature as 85C or 100C. At this temperature, protection
@@ -35,4 +36,5 @@
 
 The TjMax temperature is set to 85 degrees C if undocumented model specific
 register (UMSR) 0xee has bit 30 set. If not the TjMax is 100 degrees C as
-(sometimes) documented in processor datasheet.
+(sometimes) documented in processor datasheet. The Intel Atom has TjMax 95C
+as per the specification.
diff -Naur vanilla-2.6.29/drivers/hwmon/coretemp.c vanilla-2.6.29.coretemp/drivers/hwmon/coretemp.c
--- vanilla-2.6.29/drivers/hwmon/coretemp.c	2009-03-24 00:12:14.000000000 +0100
+++ vanilla-2.6.29.coretemp/drivers/hwmon/coretemp.c	2009-06-05 10:09:02.206624345 +0200
@@ -1,7 +1,8 @@
 /*
  * coretemp.c - Linux kernel module for hardware monitoring
  *
- * Copyright (C) 2007 Rudolf Marek <r.marek@assembler.cz>
+ * Copyright (C) 2007, 2008 Rudolf Marek <r.marek@assembler.cz>
+ * Atom patch ported by Maciej Zenczykowski <zenczykowski@gmail.com>
  *
  * Inspired from many hwmon drivers
  *
@@ -161,6 +162,13 @@
 	int err;
 	u32 eax, edx;
 
+	/* Intel Atom has a fixed TjMax at 95C */
+	if (c->x86_model == 0x1c) {
+		tjmax = 95000;
+		ismobile = 0;
+		return tjmax;
+	}
+	
 	/* Early chips have no MSR for TjMax */
 
 	if ((c->x86_model == 0xf) && (c->x86_mask < 4)) {
@@ -413,11 +421,11 @@
 	for_each_online_cpu(i) {
 		struct cpuinfo_x86 *c = &cpu_data(i);
 
 		/* check if family 6, models 0xe, 0xf, 0x16, 0x17, 0x1A */
 		if ((c->cpuid_level < 0) || (c->x86 != 0x6) ||
 		    !((c->x86_model == 0xe) || (c->x86_model == 0xf) ||
 			(c->x86_model == 0x16) || (c->x86_model == 0x17) ||
-			(c->x86_model == 0x1A))) {
+			(c->x86_model == 0x1a) || (c->x86_model == 0x1c))) {
 
 			/* supported CPU not found, but report the unknown
 			   family 6 CPU */

[-- Attachment #4: Type: text/plain, Size: 153 bytes --]

_______________________________________________
lm-sensors mailing list
lm-sensors@lm-sensors.org
http://lists.lm-sensors.org/mailman/listinfo/lm-sensors

^ permalink raw reply	[flat|nested] 5+ messages in thread

* Re: [lm-sensors] Jetway NC92-330-LF motherboard sensors.conf
  2009-06-05 11:29 [lm-sensors] Jetway NC92-330-LF motherboard sensors.conf Maciej Żenczykowski
@ 2009-06-15 12:11 ` Jean Delvare
  2009-06-15 14:27 ` Maciej Żenczykowski
                   ` (2 subsequent siblings)
  3 siblings, 0 replies; 5+ messages in thread
@@ -413,11 +421,11 @@
 		struct cpuinfo_x86 *c = &cpu_data(i);
 
-		/* check if family 6, models 0xe, 0xf, 0x16, 0x17, 0x1A */
+		/* check if family 6, models 0xe, 0xf, 0x16, 0x17, 0x1a, 0x1c */
 		if ((c->cpuid_level < 0) || (c->x86 != 0x6) ||
 		    !((c->x86_model == 0xe) || (c->x86_model == 0xf) ||
From: Jean Delvare @ 2009-06-15 12:11 UTC (permalink / raw)
  To: lm-sensors

On Fri, 5 Jun 2009 13:29:38 +0200, Maciej Żenczykowski wrote:
> submitting a sensors.conf file for a Jetway NC92-330-LF motherboard
> with f71882fg monitoring chip.
> 
> # uname -a
> Linux gaia 2.6.29.4-168.mz1.fc11.x86_64 #1 SMP Fri Jun 5 11:10:05 CEST
> 2009 x86_64 x86_64 x86_64 GNU/Linux
> 
> # lsmod | head -n 5
> Module                  Size  Used by
> f71882fg               27120  0
> coretemp                6768  0
> 
> Also including a slight patch to coretemp.c for atom support.
> 
> Hope you include the conf in the wiki.

Done, thanks for your contribution:
http://www.lm-sensors.org/wiki/Configurations/Jetway/NC92-330-LF

Note: you should really be able to tell which is the CPU temperature
sensor by putting significant load on the system and watching which
temperature value raises highest and fastest.

-- 
Jean Delvare

_______________________________________________
lm-sensors mailing list
lm-sensors@lm-sensors.org
http://lists.lm-sensors.org/mailman/listinfo/lm-sensors

^ permalink raw reply	[flat|nested] 5+ messages in thread

* Re: [lm-sensors] Jetway NC92-330-LF motherboard sensors.conf
  2009-06-05 11:29 [lm-sensors] Jetway NC92-330-LF motherboard sensors.conf Maciej Żenczykowski
  2009-06-15 12:11 ` Jean Delvare
@ 2009-06-15 14:27 ` Maciej Żenczykowski
  2009-06-15 14:29 ` Maciej Żenczykowski
  2009-06-15 14:59 ` Maciej Żenczykowski
  3 siblings, 0 replies; 5+ messages in thread
From: Maciej Żenczykowski @ 2009-06-15 14:27 UTC (permalink / raw)
  To: lm-sensors

Fair enough, but the intel atom 330 chip is only 8W TDP (passive
cooling, although using the exhaust heat from the northbridge for
cooling) and the northbridge chipset is ~20W TDP (active cooling).  As
such it's not clear exactly what to expect to get hotter faster.
They're marked the way I believe the BIOS marks them, but on an idle
machine with plenty of cooling:

Core 0:      +40.0°C  (crit = +95.0°C)
Core 1:      +41.0°C  (crit = +95.0°C)
Core 2:      +42.0°C  (crit = +95.0°C)
Core 3:      +41.0°C  (crit = +95.0°C)

CPUFAN:     1920 RPM
SYSFAN1:    3667 RPM
SYSFAN2:    2008 RPM
?CPU Temp:   +31.0°C  (high = +85.0°C, hyst = +81.0°C)
?Sys Temp:   +41.0°C  (high = +85.0°C, hyst = +81.0°C)
???? Temp:   +47.0°C  (high = +70.0°C, hyst = +68.0°C)

# cat /proc/acpi/thermal_zone/THRM/temperature
temperature:             31 C

Unfortunately the core temps may or may not be correct (they may need
an offset of +-X degrees, since it's not clear what TjMax actually is
for an atom 330, and I'm 'kind of' guessing it to be 95), and the cpu
temp being lower than the sys temp actually makes some sense...

The last temperature isn't even shown by the BIOS, but does seem to
show a kind of reasonable value (maybe it's the NB?)...

I'm guessing that the CPU does actually run cooler than the
northbridge - it's just a tad counter-intuitive.

2009/6/15 Jean Delvare <khali@linux-fr.org>:
> On Fri, 5 Jun 2009 13:29:38 +0200, Maciej Żenczykowski wrote:
>> submitting a sensors.conf file for a Jetway NC92-330-LF motherboard
>> with f71882fg monitoring chip.
>>
>> # uname -a
>> Linux gaia 2.6.29.4-168.mz1.fc11.x86_64 #1 SMP Fri Jun 5 11:10:05 CEST
>> 2009 x86_64 x86_64 x86_64 GNU/Linux
>>
>> # lsmod | head -n 5
>> Module                  Size  Used by
>> f71882fg               27120  0
>> coretemp                6768  0
>>
>> Also including a slight patch to coretemp.c for atom support.
>>
>> Hope you include the conf in the wiki.
>
> Done, thanks for your contribution:
> http://www.lm-sensors.org/wiki/Configurations/Jetway/NC92-330-LF
>
> Note: you should really be able to tell which is the CPU temperature
> sensor by putting significant load on the system and watching which
> temperature value raises highest and fastest.
>
> --
> Jean Delvare
>

_______________________________________________
lm-sensors mailing list
lm-sensors@lm-sensors.org
http://lists.lm-sensors.org/mailman/listinfo/lm-sensors

^ permalink raw reply	[flat|nested] 5+ messages in thread

* Re: [lm-sensors] Jetway NC92-330-LF motherboard sensors.conf
  2009-06-05 11:29 [lm-sensors] Jetway NC92-330-LF motherboard sensors.conf Maciej Żenczykowski
  2009-06-15 12:11 ` Jean Delvare
  2009-06-15 14:27 ` Maciej Żenczykowski
@ 2009-06-15 14:29 ` Maciej Żenczykowski
  2009-06-15 14:59 ` Maciej Żenczykowski
  3 siblings, 0 replies; 5+ messages in thread
From: Maciej Żenczykowski @ 2009-06-15 14:29 UTC (permalink / raw)
  To: lm-sensors

(In case that wasn't clear, the thing marked CPUFAN in the BIOS and in
the config is actually on the northbridge, and the exhaust from the
northbridge blows over the cpu)

2009/6/15 Maciej Żenczykowski <zenczykowski@gmail.com>:
> Fair enough, but the intel atom 330 chip is only 8W TDP (passive
> cooling, although using the exhaust heat from the northbridge for
> cooling) and the northbridge chipset is ~20W TDP (active cooling).  As
> such it's not clear exactly what to expect to get hotter faster.
> They're marked the way I believe the BIOS marks them, but on an idle
> machine with plenty of cooling:
>
> Core 0:      +40.0°C  (crit = +95.0°C)
> Core 1:      +41.0°C  (crit = +95.0°C)
> Core 2:      +42.0°C  (crit = +95.0°C)
> Core 3:      +41.0°C  (crit = +95.0°C)
>
> CPUFAN:     1920 RPM
> SYSFAN1:    3667 RPM
> SYSFAN2:    2008 RPM
> ?CPU Temp:   +31.0°C  (high = +85.0°C, hyst = +81.0°C)
> ?Sys Temp:   +41.0°C  (high = +85.0°C, hyst = +81.0°C)
> ???? Temp:   +47.0°C  (high = +70.0°C, hyst = +68.0°C)
>
> # cat /proc/acpi/thermal_zone/THRM/temperature
> temperature:             31 C
>
> Unfortunately the core temps may or may not be correct (they may need
> an offset of +-X degrees, since it's not clear what TjMax actually is
> for an atom 330, and I'm 'kind of' guessing it to be 95), and the cpu
> temp being lower than the sys temp actually makes some sense...
>
> The last temperature isn't even shown by the BIOS, but does seem to
> show a kind of reasonable value (maybe it's the NB?)...
>
> I'm guessing that the CPU does actually run cooler than the
> northbridge - it's just a tad counter-intuitive.
>
> 2009/6/15 Jean Delvare <khali@linux-fr.org>:
>> On Fri, 5 Jun 2009 13:29:38 +0200, Maciej Żenczykowski wrote:
>>> submitting a sensors.conf file for a Jetway NC92-330-LF motherboard
>>> with f71882fg monitoring chip.
>>>
>>> # uname -a
>>> Linux gaia 2.6.29.4-168.mz1.fc11.x86_64 #1 SMP Fri Jun 5 11:10:05 CEST
>>> 2009 x86_64 x86_64 x86_64 GNU/Linux
>>>
>>> # lsmod | head -n 5
>>> Module                  Size  Used by
>>> f71882fg               27120  0
>>> coretemp                6768  0
>>>
>>> Also including a slight patch to coretemp.c for atom support.
>>>
>>> Hope you include the conf in the wiki.
>>
>> Done, thanks for your contribution:
>> http://www.lm-sensors.org/wiki/Configurations/Jetway/NC92-330-LF
>>
>> Note: you should really be able to tell which is the CPU temperature
>> sensor by putting significant load on the system and watching which
>> temperature value raises highest and fastest.
>>
>> --
>> Jean Delvare
>>
>

_______________________________________________
lm-sensors mailing list
lm-sensors@lm-sensors.org
http://lists.lm-sensors.org/mailman/listinfo/lm-sensors

^ permalink raw reply	[flat|nested] 5+ messages in thread

* Re: [lm-sensors] Jetway NC92-330-LF motherboard sensors.conf
  2009-06-05 11:29 [lm-sensors] Jetway NC92-330-LF motherboard sensors.conf Maciej Żenczykowski
                   ` (2 preceding siblings ...)
  2009-06-15 14:29 ` Maciej Żenczykowski
@ 2009-06-15 14:59 ` Maciej Żenczykowski
  3 siblings, 0 replies; 5+ messages in thread
From: Maciej Żenczykowski @ 2009-06-15 14:59 UTC (permalink / raw)
  To: lm-sensors

Running mprime295-linux64 test 2 = In-place large FFTs (maximum heat
and power consumption, some RAM
tested) with 4 threads.

Core 0:      +55.0°C  (crit = +95.0°C)
Core 1:      +58.0°C  (crit = +95.0°C)
Core 2:      +58.0°C  (crit = +95.0°C)
Core 3:      +55.0°C  (crit = +95.0°C)
?CPU Temp:   +47.0°C  (high = +85.0°C, hyst = +81.0°C)
?Sys Temp:   +43.0°C  (high = +85.0°C, hyst = +81.0°C)
???? Temp:   +47.0°C  (high = +70.0°C, hyst = +68.0°C)

ACPI THRM temperature:             47 C [so this is probably just CPU Temp]

So '?CPU Temp' is probably indeed CPU Temp, but the other two are
still unclear (especially the third one, which does oscillate a
little, seen 45-48).

The Core Temps do seem to be consistently about ~10 C higher than CPU
Temp, which suggest that TjMax is probably closer to 90 C [instead of
the assumed 95 C].  Since usually core temps are about 5 C higher than
cpu case temp, assuming that that is indeed what is being measured
here.  Which also is in compliance with the thermal spec of an atom
330 being 85.2C [
http://processorfinder.intel.com/details.aspx?sSpec=SLG9Y ] (+~5C case
max to junction max gives a 90C TjMax).  But it's really all just
guess-work...

Unfortunately my setup has rather good cooling (ran into issues with
the 2 HDDs overheating and opened up the case and added an extra huge
fan).  And as I don't currently have physical access to it (it's on
the other side of the pond) I'm not willing to dial it down.

Anyway... to actually include some useful content in this email.  How
are we going to proceed with the atom coretemp patch? [forward ported
from http://bugzilla.kernel.org/show_bug.cgi?id\x11161 ]

Cheers,
Maciej

2009/6/15 Maciej Żenczykowski <zenczykowski@gmail.com>:
> (In case that wasn't clear, the thing marked CPUFAN in the BIOS and in
> the config is actually on the northbridge, and the exhaust from the
> northbridge blows over the cpu)
>
> 2009/6/15 Maciej Żenczykowski <zenczykowski@gmail.com>:
>> Fair enough, but the intel atom 330 chip is only 8W TDP (passive
>> cooling, although using the exhaust heat from the northbridge for
>> cooling) and the northbridge chipset is ~20W TDP (active cooling).  As
>> such it's not clear exactly what to expect to get hotter faster.
>> They're marked the way I believe the BIOS marks them, but on an idle
>> machine with plenty of cooling:
>>
>> Core 0:      +40.0°C  (crit = +95.0°C)
>> Core 1:      +41.0°C  (crit = +95.0°C)
>> Core 2:      +42.0°C  (crit = +95.0°C)
>> Core 3:      +41.0°C  (crit = +95.0°C)
>>
>> CPUFAN:     1920 RPM
>> SYSFAN1:    3667 RPM
>> SYSFAN2:    2008 RPM
>> ?CPU Temp:   +31.0°C  (high = +85.0°C, hyst = +81.0°C)
>> ?Sys Temp:   +41.0°C  (high = +85.0°C, hyst = +81.0°C)
>> ???? Temp:   +47.0°C  (high = +70.0°C, hyst = +68.0°C)
>>
>> # cat /proc/acpi/thermal_zone/THRM/temperature
>> temperature:             31 C
>>
>> Unfortunately the core temps may or may not be correct (they may need
>> an offset of +-X degrees, since it's not clear what TjMax actually is
>> for an atom 330, and I'm 'kind of' guessing it to be 95), and the cpu
>> temp being lower than the sys temp actually makes some sense...
>>
>> The last temperature isn't even shown by the BIOS, but does seem to
>> show a kind of reasonable value (maybe it's the NB?)...
>>
>> I'm guessing that the CPU does actually run cooler than the
>> northbridge - it's just a tad counter-intuitive.
>>
>> 2009/6/15 Jean Delvare <khali@linux-fr.org>:
>>> On Fri, 5 Jun 2009 13:29:38 +0200, Maciej Żenczykowski wrote:
>>>> submitting a sensors.conf file for a Jetway NC92-330-LF motherboard
>>>> with f71882fg monitoring chip.
>>>>
>>>> # uname -a
>>>> Linux gaia 2.6.29.4-168.mz1.fc11.x86_64 #1 SMP Fri Jun 5 11:10:05 CEST
>>>> 2009 x86_64 x86_64 x86_64 GNU/Linux
>>>>
>>>> # lsmod | head -n 5
>>>> Module                  Size  Used by
>>>> f71882fg               27120  0
>>>> coretemp                6768  0
>>>>
>>>> Also including a slight patch to coretemp.c for atom support.
>>>>
>>>> Hope you include the conf in the wiki.
>>>
>>> Done, thanks for your contribution:
>>> http://www.lm-sensors.org/wiki/Configurations/Jetway/NC92-330-LF
>>>
>>> Note: you should really be able to tell which is the CPU temperature
>>> sensor by putting significant load on the system and watching which
>>> temperature value raises highest and fastest.
>>>
>>> --
>>> Jean Delvare
>>>
>>
>

_______________________________________________
lm-sensors mailing list
lm-sensors@lm-sensors.org
http://lists.lm-sensors.org/mailman/listinfo/lm-sensors

^ permalink raw reply	[flat|nested] 5+ messages in thread

end of thread, other threads:[~2009-06-15 14:59 UTC | newest]

Thread overview: 5+ messages (download: mbox.gz follow: Atom feed
-- links below jump to the message on this page --
2009-06-05 11:29 [lm-sensors] Jetway NC92-330-LF motherboard sensors.conf Maciej Żenczykowski
2009-06-15 12:11 ` Jean Delvare
2009-06-15 14:27 ` Maciej Żenczykowski
2009-06-15 14:29 ` Maciej Żenczykowski
2009-06-15 14:59 ` Maciej Żenczykowski

This is an external index of several public inboxes,
see mirroring instructions on how to clone and mirror
all data and code used by this external index.